@@ -1,7 +1,7 @@
 package Org::Element::Timestamp;
 
-our $DATE = '2017-07-10'; # DATE
-our $VERSION = '0.54'; # VERSION
+our $DATE = '2019-02-08'; # DATE
+our $VERSION = '0.550'; # VERSION
 
 use 5.010;
 use locale;
@@ -94,9 +94,9 @@ sub _parse_timestamp {
                    /x;
 
     $str =~ /^(?<open_bracket> \[|<)
-             (?<year> \d{4})-(?<mon> \d{2})-(?<day> \d{2}) \s*
+             (?<year> \d{4})-(?<mon> \d{2})-(?<day> \d{2})
              (?:
-                 (?<dow> $dow_re) \s*?
+                 (?:\s* (?<dow> $dow_re) \s*)?
                  (?:\s+
                      (?<hour> \d{2}):(?<min> \d{2})
                      (?:-
@@ -119,7 +119,7 @@ sub _parse_timestamp {
                      )
                  )?
              )?
-             (?<close_bracket> \]|>)
+             \s* (?<close_bracket> \]|>)
              $/x
                  or die "Can't parse timestamp string: $str";
     # just for sanity. usually doesn't happen though because Document gives us
@@ -211,7 +211,7 @@ Org::Element::Timestamp - Represent Org timestamp
 
 =head1 VERSION
 
-This document describes version 0.54 of Org::Element::Timestamp (from Perl distribution Org-Parser), released on 2017-07-10.
+This document describes version 0.550 of Org::Element::Timestamp (from Perl distribution Org-Parser), released on 2019-02-08.
 
 =head1 DESCRIPTION
 
@@ -307,7 +307,7 @@ perlancar <perlancar@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2017, 2016, 2015, 2014, 2013, 2012, 2011 by perlancar@cpan.org.
+This software is copyright (c) 2019, 2017, 2016, 2015, 2014, 2013, 2012, 2011 by perlancar@cpan.org.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
